@@ -170,6 +170,7 @@ func (fluent *fluentReceiverLogStore) ApplicationLogs(timeToWait time.Duration)
 func (fluent fluentReceiverLogStore) HasInfraStructureLogs(timeToWait time.Duration) (bool, error) {
 	return fluent.hasLogs("/tmp/infra.logs", timeToWait)
 }
+
 func (fluent *fluentReceiverLogStore) HasApplicationLogs(timeToWait time.Duration) (bool, error) {
 	return fluent.hasLogs("/tmp/app.logs", timeToWait)
 }
@@ -274,7 +275,7 @@ func (tc *E2ETestFramework) DeployFluentdReceiver(rootDir string, secure bool) (
 	}
 	container := corev1.Container{
 		Name:            receiverName,
-		Image:           "quay.io/openshift-logging/fluentd:latest",
+		Image:           "quay.io/openshift-logging/fluentd:1.7.4",
 		ImagePullPolicy: corev1.PullAlways,
 		Args:            []string{"fluentd", "-c", "/fluentd/etc/fluent.conf"},
 		VolumeMounts: []corev1.VolumeMount{
